@@ -1,5 +1,5 @@
 package Git::Raw::Repository;
-$Git::Raw::Repository::VERSION = '0.34'; # TRIAL
+$Git::Raw::Repository::VERSION = '0.36'; # TRIAL
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ Git::Raw::Repository - Git repository class
 
 =head1 VERSION
 
-version 0.34
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -92,11 +92,6 @@ Textual progress from the remote. Text send over the progress side-band will be
 passed to this function (this is the 'counting objects' output). The callback
 receives a string containing progress information.
 
-=item * "completion"
-
-Completion is called when different parts of the download process are done
-(currently unused).
-
 =item * "transfer_progress"
 
 During the download of new data, this will be regularly called with the current
